==> gammaray_2.3.0.orig.tar.gz: gammaray-2.3.0/plugins/widgetinspector/widgetinspectorclient.cpp <==
/*
 * widgetinspectorclient.cpp
 *
 * This file is part of GammaRay, the Qt application inspection and
 * manipulation tool.
 *
 * Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 * Author: Milian Wolff <milian.wolff@kdab.com>
 *
 * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
 * accordance with GammaRay Commercial License Agreement provided with the Software.
 *
 * Contact info@kdab.com if any conditions of this licensing are not clear to you.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "widgetinspectorclient.h"
#include <common/endpoint.h>

using namespace GammaRay;

WidgetInspectorClient::WidgetInspectorClient(QObject *parent)
  : WidgetInspectorInterface(parent)
{
}

WidgetInspectorClient::~WidgetInspectorClient()
{
}

#define WRAP_REMOTE(func, type) \
void WidgetInspectorClient::func(type arg) \
{ \
  Endpoint::instance()->invokeObject(objectName(), #func, QVariantList() << arg); \
}

WRAP_REMOTE(saveAsImage, const QString &)
WRAP_REMOTE(saveAsPdf, const QString &)
WRAP_REMOTE(saveAsSvg, const QString &)
WRAP_REMOTE(saveAsUiFile, const QString &)

void WidgetInspectorClient::analyzePainting()
{
  Endpoint::instance()->invokeObject(objectName(), "analyzePainting");
}

void WidgetInspectorClient::checkFeatures()
{
  Endpoint::instance()->invokeObject(objectName(), "checkFeatures");
}

==> gammaray_2.11.0.orig.tar.gz: gammaray-2.11.0/plugins/widgetinspector/widgetinspectorclient.cpp <==
/*
 * widgetinspectorclient.cpp
 *
 * This file is part of GammaRay, the Qt application inspection and
 * manipulation tool.
 *
 * Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 * Author: Milian Wolff <milian.wolff@kdab.com>
 *
 * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
 * accordance with GammaRay Commercial License Agreement provided with the Software.
 *
 * Contact info@kdab.com if any conditions of this licensing are not clear to you.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "widgetinspectorclient.h"
#include <common/endpoint.h>

using namespace GammaRay;

WidgetInspectorClient::WidgetInspectorClient(QObject *parent)
    : WidgetInspectorInterface(parent)
{
}

WidgetInspectorClient::~WidgetInspectorClient() = default;

#define WRAP_REMOTE(func, type) \
    void WidgetInspectorClient::func(type arg) \
    { \
        Endpoint::instance()->invokeObject(objectName(), #func, QVariantList() << arg); \
    }

WRAP_REMOTE(saveAsImage, const QString &)
WRAP_REMOTE(saveAsPdf, const QString &)
WRAP_REMOTE(saveAsSvg, const QString &)
WRAP_REMOTE(saveAsUiFile, const QString &)

void WidgetInspectorClient::analyzePainting()
{
    Endpoint::instance()->invokeObject(objectName(), "analyzePainting");
}
